@@ -3,7 +3,6 @@ use warnings;
 use lib 'lib';
 use t::Util;
 use File::Spec;
-use Benchmark qw/cmpthese timethese/;
 
 use DBIx::QueryLog ();
 
@@ -14,7 +13,7 @@ open STDERR, '>', File::Spec->devnull or die $!;
 
 my $enabled;
 my $disabled;
-cmpthese timethese 0, {
+cmpthese 5000, {
     original => sub {
         DBIx::QueryLog->unimport unless $disabled++;
         $dbh->selectrow_arrayref('SELECT * FROM sqlite_master WHERE name = ?', undef, 'foo');
